@@ -173,7 +173,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         for log in logs_data:
             for item in log.items:
                 alpha = {
-                    "Timestamp": log.timestamp * 1000,
+                    "Timestamp": str(log.timestamp * 1000),
                     "Data": {
                         "event": item.key,
                         "message": item.val.get("err_msg"),
