@@ -9,61 +9,40 @@ import os
 import re
 import uuid
 
-# try:
-#     import ConfigParser
-# except ImportError:
-#     import configparser as ConfigParser
-
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from typing import List
-
 RE_IGNORE_PATH = os.getenv("FastTracker_ReIgnorePath") or re.compile("^$")  # type: re.Pattern
 
 service_instance = os.getenv("FastTracker_Instance") or str(uuid.uuid1()).replace("-", "")  # type: str
 protocol = (os.getenv("FastTracker_Protocol") or "udp").lower()  # type: str
-authentication = os.getenv("FastTracker_Authentication")  # type: str
-# logging_level = os.getenv("FastTrackerLoggingLevel") or "INFO"  # type: str
-# 禁用插件列表 plugins init文件中会使用到，也可以使用FAST_TRACKER_AGENT_DISABLE_PLUGINS申明禁用
-disable_plugins = (os.getenv("FastTracker_DisablePlugins") or "").split(",")  # type: List[str]
 ignore_suffix = (
     os.getenv("FastTracker_IgnoreSuffix") or ".jpg,.jpeg,.js,.css,.png,.bmp,.gif,.ico,.mp3," ".mp4,.html,.svg "
 )  # type: str
-http_params_length_threshold = int(os.getenv("FastTracker_HttpParamsLengthThreshold") or "1024")  # type: int
-django_collect_http_params = (
-    True
-    if os.getenv("FastTracker_DjangoCollectHttpParams") and os.getenv("FastTracker_DjangoCollectHttpParams") == "True"
-    else False
-)  # type: bool
 correlation_element_max_number = int(os.getenv("FastTracker_CorrelationElementMaxNumber") or "3")  # type: int
 correlation_value_max_length = int(os.getenv("FastTracker_CorrelationValueMaxLength") or "128")  # type: int
 trace_ignore_path = os.getenv("FastTracker_IgnorePath") or ""  # type: str
 
 ############################# fast_tracker默认配置信息开始 ###############################
 # agent全局开关，默认false
-enable = True if os.getenv("FastTracker_Enable") and os.getenv("FastTracker_Enable") == "True" else False  # type: bool
+enable = False  # type: bool
 # 环境编码 默认test
-env_code = os.getenv("FastTracker_EnvCode") or "test"  # type: str
+env_code = "test"  # type: str
 # 日志等级 默认 DEBUG
-# log_level = os.getenv("FastTrackerLogLevel") or "DEBUG"  # type: str
-log_level = os.getenv("FastTracker_LogLevel") or "ERROR"  # type: str
+log_level = "ERROR"  # type: str
 # 租户编码 默认zsdc
-tenant_code = os.getenv("FastTracker_TenantCode") or "zsdc"  # type: str
+tenant_code = ""  # type: str
 # 用户编码 默认zhangsan
-user_code = os.getenv("FastTracker_UserCode") or "zhangsan"  # type: str
+user_code = ""  # type: str
 # 服务名称 默认"天眼平台"
-service_name = os.getenv("FastTracker_ServiceName") or "天眼平台"  # type: str
+service_name = ""  # type: str
 # 产品编码 默认fast
-product_code = os.getenv("FastTracker_ProductCode") or "fast"  # type: str
+product_code = ""  # type: str
 # 服务编码 默认"analysis"
-app_code = os.getenv("FastTracker_AppCode") or "analysis"  # type: str
+app_code = ""  # type: str
 # 上报地址 默认"udp://127.0.0.1:5140"
-collector_address = os.getenv("FastTracker_SocketPath") or "udp://fluent-bit:5140"  # type: str
+collector_address = ""  # type: str
 # 缓冲区大小 默认1
-buffer_size = os.getenv("FastTracker_BufferSize") or 1  # type: int
+buffer_size = 1  # type: int
 # 上报超时时间 默认1（秒）
-socket_timeout = os.getenv("FastTracker_SocketTimeout") or 1  # type: int
+socket_timeout = 1  # type: int
 # 兼容原Event模块，目前一般只有Components
 event = {"Components": {"SqlClient": True, "HttpClient": True}}
 # 租户code，一般SaaS化租户会在运行时才知道此值，所以动态传值，ReaderType表示从哪里获取，ReaderKey表示字段名称
@@ -80,24 +59,20 @@ carrier_header = {"TrackerName": "fast-tracker", "TraceIdName": "x-fast-trace-id
 
 
 def init(
-    service: str = None,
-    instance: str = None,
-    collector: str = None,
-    protocol_type: str = "udp",
-    token: str = None,
+    service: str = None, instance: str = None, collector: str = None, protocol_type: str = "udp", token: str = None
 ):
-    # 根据环境变量 FastTracker.ConfigPath 加载配置文件
+    # 先根据环境变量 FastTracker_ConfigPath 加载配置文件并赋值
     config_file = os.environ.get("FastTracker_ConfigPath", None)
-    print("FastTracker_ConfigPath:", config_file)
-    if config_file:
-        # _load_configuration(config_file)
-        from fast_tracker.fast_tracker_configer import FastTrackerConfiger
+    print("FAST: FastTracker_ConfigPath is %s " % config_file)
+    from fast_tracker.fast_tracker_configer import FastTrackerConfiger
 
+    if config_file:
         FastTrackerConfiger.load_configuration(config_file)
 
-    # 环境变量更新config信息
-    set_config_from_env()
+    # 再根据环境变量加载配置
+    FastTrackerConfiger.set_config_by_env()
 
+    # 再自定义设置的配置
     global service_name
     service_name = service or service_name
 
@@ -110,53 +85,6 @@ def init(
     global protocol
     protocol = protocol_type or protocol
 
-    global authentication
-    authentication = token or authentication
-
-def set_config_from_env():
-    """
-    根据环境变量更新配置
-    :return:
-    """
-    global enable
-    # agent全局开关，默认false
-    enable = True if os.getenv("FastTracker_Enable") and os.getenv(
-        "FastTracker_Enable") == "True" else False  # type: bool
-    # 环境编码 默认test
-    env_code = os.getenv("FastTracker_EnvCode") or "test"  # type: str
-    # 日志等级 默认 DEBUG
-    # log_level = os.getenv("FastTrackerLogLevel") or "DEBUG"  # type: str
-    log_level = os.getenv("FastTracker_LogLevel") or "ERROR"  # type: str
-    # 租户编码 默认zsdc
-    tenant_code = os.getenv("FastTracker_TenantCode") or "zsdc"  # type: str
-    # 用户编码 默认zhangsan
-    user_code = os.getenv("FastTracker_UserCode") or "zhangsan"  # type: str
-    # 服务名称 默认"天眼平台"
-    service_name = os.getenv("FastTracker_ServiceName") or "天眼平台"  # type: str
-    # 产品编码 默认fast
-    product_code = os.getenv("FastTracker_ProductCode") or "fast"  # type: str
-    # 服务编码 默认"analysis"
-    app_code = os.getenv("FastTracker_AppCode") or "analysis"  # type: str
-    # 上报地址 默认"udp://127.0.0.1:5140"
-    collector_address = os.getenv("FastTracker_SocketPath") or "udp://fluent-bit:5140"  # type: str
-    # 缓冲区大小 默认1
-    buffer_size = os.getenv("FastTracker_BufferSize") or 1  # type: int
-    # 上报超时时间 默认1（秒）
-    socket_timeout = os.getenv("FastTracker_SocketTimeout") or 1  # type: int
-    # 兼容原Event模块，目前一般只有Components
-    event = {"Components": {"SqlClient": True, "HttpClient": True}}
-    # 租户code，一般SaaS化租户会在运行时才知道此值，所以动态传值，ReaderType表示从哪里获取，ReaderKey表示字段名称
-    # tenant_code_reader = {"ReaderType": "Cookie", "ReaderKey": "tenant_code"}
-    # tenant_code_reader = {"ReaderType": "RequestHeader", "ReaderKey": "tcode"}
-    tenant_code_reader = {"ReaderType": "QueryString", "ReaderKey": "tentcode"}
-    # 用户code，一般会在运行时才知道此值，所以动态传值，ReaderType表示从哪里获取，ReaderKey表示字段名称
-    user_code_reader = {"ReaderType": "Cookie", "ReaderKey": "user_code"}
-    # 环境code，一般会在运行时才知道此值，所以动态传值，ReaderType表示从哪里获取，ReaderKey表示字段名称
-    env_code_reader = {"ReaderType": "Cookie", "ReaderKey": "env_code"}
-    # 前端Header
-    carrier_header = {"TrackerName": "fast-tracker", "TraceIdName": "x-fast-trace-id"}
-
-
 
 def set_enable(cus_enable: bool = False):
     """
@@ -220,7 +148,7 @@ def set_app_code(cus_app_code: str = ""):
 
 def set_service_name(cus_service_name: str = ""):
     """
-    设置service_name值
+    设置 service_name 值
     :param cus_service_name:
     :return:
     """
@@ -230,7 +158,7 @@ def set_service_name(cus_service_name: str = ""):
 
 def set_socket_path(cus_collector_address: str = ""):
     """
-    设置collector_address值
+    设置 collector_address 值
     :param cus_collector_address:
     :return:
     """
@@ -240,7 +168,7 @@ def set_socket_path(cus_collector_address: str = ""):
 
 def set_buffer_size(cus_buffer_size: int = 1):
     """
-    设置buffer_size值
+    设置 buffer_size 值
     :param cus_buffer_size:
     :return:
     """
@@ -250,7 +178,7 @@ def set_buffer_size(cus_buffer_size: int = 1):
 
 def set_socket_timeout(cus_socket_timeout: int = 1):
     """
-    设置socket_timeout值
+    设置 socket_timeout 值
     :param cus_socket_timeout:
     :return:
     """
@@ -260,7 +188,7 @@ def set_socket_timeout(cus_socket_timeout: int = 1):
 
 def set_event(cus_event: dict):
     """
-    设置event值
+    设置 event 值
     :param cus_event:
     :return:
     """
@@ -272,7 +200,7 @@ def set_event(cus_event: dict):
 
 def set_tenant_code_reader(cus_tenant_code_reader: dict):
     """
-    设置tenant_code_reader值
+    设置 tenant_code_reader 值
     :param cus_tenant_code_reader:
     :return:
     """
@@ -284,7 +212,7 @@ def set_tenant_code_reader(cus_tenant_code_reader: dict):
 
 def set_user_code_reader(cus_user_code_reader: dict):
     """
-    设置user_code_reader值
+    设置 user_code_reader 值
     :param cus_user_code_reader:
     :return:
     """
@@ -296,7 +224,7 @@ def set_user_code_reader(cus_user_code_reader: dict):
 
 def set_carrier_header(cus_carrier_header: dict):
     """
-    设置carrier_header值
+    设置 carrier_header 值
     :param cus_carrier_header:
     :return:
     """
@@ -306,6 +234,18 @@ def set_carrier_header(cus_carrier_header: dict):
     carrier_header = cus_carrier_header
 
 
+def set_env_code_reader(cus_env_code_reader: dict):
+    """
+    设置 env_code_reader 值
+    :param cus_env_code_reader:
+    :return:
+    """
+    global env_code_reader
+    if not cus_env_code_reader:
+        return False
+    env_code_reader = cus_env_code_reader
+
+
 def set_trace_id_name(trace_id_name: str):
     """
     设置trace_id_name
